Security Advisories (3)
CVE-2016-1238 (2016-08-02)

Imager would search the default current directory entry in @INC when searching for file format support modules.

CPANSA-Imager-2014-01 (2014-01-03)

When drawing on an image with an alpha channel where the source minimum is greater than zero, Imager would read from beyond the end of a malloc() allocated buffer. In rare circumstances this could lead to some of the source image not being written to the target image, or possibly to a segmentation fault.

CVE-2024-53901 (2024-11-17)

"invalid next size" backtrace on use of trim on certain images

NAME

Imager::ExtUtils - functions handy in writing Imager extensions

SYNOPSIS

# make Imager easier to use with Inline
# perldoc Imager::Inline
use Inline with => 'Imager';

DESCRIPTION

base_dir

Returns the base directory where Imager is installed.

inline_config

Implements Imager's Inline::C with hook.

includes

Returns -I options suitable for use with ExtUtils::MakeMaker's INC option.

typemap

Returns the full path to Imager's installed typemap.

AUTHOR

Tony Cook <tonyc@cpan.org>

REVISION

$Revision$

SEE ALSO

Imager, Imager::API, Imager::Inline, Imager::APIRef.